@@ -115,13 +115,13 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *cmd,
 	snprintf(buf, sizeof(buf), "cmd=%s&session=%s&dest=%s&data=%s&ts=%i", hex_cmd, hex_session, hex_dest, hex_data, (unsigned int) time(NULL));
 	buf[sizeof(buf)-1]='\0';
 	fprintf(fp, "POST %s HTTP/1.0\r\nHost: %s\r\nContent-length: %i\r\n\r\n%s", hex_path, http_host, strlen(buf), buf);
-	PRINTERR("POST http://%s:%i%s?%s HTTP/1.0\n", http_host, http_port, hex_path, buf);
+	PRINTERR("POST http://%s:%i%s?[%i]%s HTTP/1.0\n", http_host, http_port, hex_path, strlen(buf), buf);
 	fflush(fp);
 
 	if (status) *status=0;
 	if (datalen) *datalen=0;
 	if (fgets(buf, sizeof(buf), fp)==NULL) return(NULL);
-	if (strstr(buf,"HTTP/1.1 40")) {
+	if (strstr(buf," 40")) {
 		PRINTERR("File not available error, %s", buf);
 		if (hex_cmd) free(hex_cmd);
 		if (hex_session) free(hex_session);
@@ -131,7 +131,7 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *cmd,
 		fclose(fp);
 		return(NULL);
 	}
-	if (!strstr(buf, "HTTP/1.1 200 ")) {
+	if (!strstr(buf, " 200 ")) {
 		PRINTERR("Invalid response, %s", buf);
 		if (hex_cmd) free(hex_cmd);
 		if (hex_session) free(hex_session);
@@ -408,6 +408,7 @@ int main(int argc, char **argv) {
 
 
 	signal(SIGALRM, sighandler);
+	signal(SIGPIPE, SIG_IGN);
 	masterfd=createlisten(listen_port);
 	if (masterfd<0) {
 		PERROR("createlisten()");
